@@ -140,6 +140,53 @@ describe 'apache', :type => :class do
         it { should contain_file("/etc/apache2/apache2.conf").with_content %r{^Group www-data\n} }
       end
     end
+
+    describe "Add extra LogFormats" do
+      context "When parameter log_formats is a hash" do
+        let :params do
+          { :log_formats => {
+            'vhost_common'   => "%v %h %l %u %t \"%r\" %>s %b",
+            'vhost_combined' => "%v %h %l %u %t \"%r\" %>s %b \"%{Referer}i\" \"%{User-agent}i\""
+          } }
+        end
+
+        it { should contain_file("/etc/apache2/apache2.conf").with_content %r{^LogFormat "%v %h %l %u %t \"%r\" %>s %b" vhost_common\n} }
+        it { should contain_file("/etc/apache2/apache2.conf").with_content %r{^LogFormat "%v %h %l %u %t \"%r\" %>s %b \"%{Referer}i\" \"%{User-agent}i\"" vhost_combined\n} }
+      end
+    end
+
+    context "on Ubuntu" do
+      let :facts do
+        super().merge({
+          :operatingsystem => 'Ubuntu'
+        })
+      end
+
+      context "13.10" do
+        let :facts do
+          super().merge({
+            :operatingsystemrelease => '13.10'
+          })
+        end
+        it { should contain_class('apache').with_apache_version('2.4') }
+      end
+      context "12.04" do
+        let :facts do
+          super().merge({
+            :operatingsystemrelease => '12.04'
+          })
+        end
+        it { should contain_class('apache').with_apache_version('2.2') }
+      end
+      context "13.04" do
+        let :facts do
+          super().merge({
+            :operatingsystemrelease => '13.04'
+          })
+        end
+        it { should contain_class('apache').with_apache_version('2.2') }
+      end
+    end
   end
   context "on a RedHat 5 OS" do
     let :facts do
@@ -493,4 +540,18 @@ describe 'apache', :type => :class do
       it { should contain_apache__vhost('default-ssl').with_ensure('present') }
     end
   end
+  context 'with unsupported osfamily' do
+    let :facts do
+      { :osfamily        => 'Darwin',
+        :operatingsystemrelease => '13.1.0',
+        :concat_basedir         => '/dne',
+      }
+    end
+
+    it do
+      expect {
+       should compile
+      }.to raise_error(Puppet::Error, /Unsupported osfamily/)
+    end
+  end
 end
