@@ -10,7 +10,7 @@ describe 'apache::mod::dav_svn', :type => :class do
         :concat_basedir         => '/dne',
       }
     end
-    it { should include_class("apache::params") }
+    it { should contain_class("apache::params") }
     it { should contain_apache__mod('dav_svn') }
     it { should contain_package("libapache2-svn") }
   end
@@ -22,7 +22,7 @@ describe 'apache::mod::dav_svn', :type => :class do
         :concat_basedir         => '/dne',
       }
     end
-    it { should include_class("apache::params") }
+    it { should contain_class("apache::params") }
     it { should contain_apache__mod('dav_svn') }
     it { should contain_package("mod_dav_svn") }
   end
@@ -34,7 +34,7 @@ describe 'apache::mod::dav_svn', :type => :class do
         :concat_basedir         => '/dne',
       }
     end
-    it { should include_class("apache::params") }
+    it { should contain_class("apache::params") }
     it { should contain_apache__mod('dav_svn') }
     it { should contain_package("devel/subversion") }
   end
