@@ -10,7 +10,7 @@ describe 'apache::mod::fcgid', :type => :class do
         :concat_basedir         => '/dne',
       }
     end
-    it { should include_class("apache::params") }
+    it { should contain_class("apache::params") }
     it { should contain_apache__mod('fcgid') }
     it { should contain_package("libapache2-mod-fcgid") }
   end
@@ -22,7 +22,7 @@ describe 'apache::mod::fcgid', :type => :class do
         :concat_basedir         => '/dne',
       }
     end
-    it { should include_class("apache::params") }
+    it { should contain_class("apache::params") }
     it { should contain_apache__mod('fcgid') }
     it { should contain_package("mod_fcgid") }
   end
@@ -34,7 +34,7 @@ describe 'apache::mod::fcgid', :type => :class do
         :concat_basedir         => '/dne',
       }
     end
-    it { should include_class("apache::params") }
+    it { should contain_class("apache::params") }
     it { should contain_apache__mod('fcgid') }
     it { should contain_package("www/mod_fcgid") }
   end
