@@ -10,7 +10,7 @@ describe 'apache::mod::python', :type => :class do
         :concat_basedir         => '/dne',
       }
     end
-    it { should include_class("apache::params") }
+    it { should contain_class("apache::params") }
     it { should contain_apache__mod("python") }
     it { should contain_package("libapache2-mod-python") }
   end
@@ -22,7 +22,7 @@ describe 'apache::mod::python', :type => :class do
         :concat_basedir         => '/dne',
       }
     end
-    it { should include_class("apache::params") }
+    it { should contain_class("apache::params") }
     it { should contain_apache__mod("python") }
     it { should contain_package("mod_python") }
   end
@@ -34,7 +34,7 @@ describe 'apache::mod::python', :type => :class do
         :concat_basedir         => '/dne',
       }
     end
-    it { should include_class("apache::params") }
+    it { should contain_class("apache::params") }
     it { should contain_apache__mod("python") }
     it { should contain_package("www/mod_python3") }
   end
