@@ -269,7 +269,7 @@ describe 'apache::vhost', :type => :define do
           :attr  => 'scriptalias',
           :value => '/usr/scripts',
           :match => [
-            /^  ScriptAlias \/cgi-bin\/ "\/usr\/scripts"$/,
+            /^  ScriptAlias \/cgi-bin "\/usr\/scripts"$/,
           ],
         },
         {
@@ -686,6 +686,7 @@ describe 'apache::vhost', :type => :define do
             'options'           => '-MultiViews',
             'order'             => 'deny,yned',
             'passenger_enabled' => 'onf',
+            'sethandler'        => 'None',
           },
           :match    => [
             /^  <Directory "\/opt\/app">$/,
@@ -695,6 +696,7 @@ describe 'apache::vhost', :type => :define do
             /^    Deny from google.com$/,
             /^    Options -MultiViews$/,
             /^    Order deny,yned$/,
+            /^    SetHandler None$/,
             /^    PassengerEnabled onf$/,
             /^  <\/Directory>$/,
           ],
@@ -1096,16 +1098,18 @@ describe 'apache::vhost', :type => :define do
           expect { subject }.to raise_error(Puppet::Error, /'error_log_file' and 'error_log_pipe' cannot be defined at the same time/)
         end
       end
-      describe 'when docroot owner is specified' do
+      describe 'when docroot owner and mode is specified' do
         let :params do default_params.merge({
           :docroot_owner => 'testuser',
           :docroot_group => 'testgroup',
+          :docroot_mode  => '0750',
         }) end
-        it 'should set vhost ownership' do
+        it 'should set vhost ownership and permissions' do
           should contain_file(params[:docroot]).with({
             :ensure => :directory,
             :owner  => 'testuser',
             :group  => 'testgroup',
+            :mode   => '0750',
           })
         end
       end
@@ -1179,6 +1183,17 @@ describe 'apache::vhost', :type => :define do
         end
       end
 
+      describe 'when action is specified specified' do
+        let :params do default_params.merge({
+          :action => 'php-fastcgi',
+        }) end
+        it 'should set Action' do
+          should contain_file("25-#{title}.conf").with_content(
+            /^  Action php-fastcgi \/cgi-bin virtual$/
+          )
+        end
+      end
+
       describe 'when suphp_engine is on and suphp_configpath is specified' do
         let :params do default_params.merge({
           :suphp_engine     => 'on',
@@ -1295,6 +1310,16 @@ describe 'apache::vhost', :type => :define do
         end
       end
 
+      describe 'when suexec_user_group is specified' do
+        let :params do
+          default_params.merge({
+            :suexec_user_group => 'nobody nogroup',
+          })
+        end
+
+        it { should contain_file("25-#{title}.conf").with_content %r{^  SuexecUserGroup nobody nogroup$} }
+      end
+
       describe 'redirect rules' do
         describe 'without lockstep arrays' do
           let :params do
